/*! @name videojs-css @version 1.2.0 @license MIT */
'use strict';

var _inheritsLoose = require('@babel/runtime/helpers/inheritsLoose');
var videojs = require('video.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _inheritsLoose__default = /*#__PURE__*/_interopDefaultLegacy(_inheritsLoose);
var videojs__default = /*#__PURE__*/_interopDefaultLegacy(videojs);

var version = "1.2.0";

var Plugin = videojs__default['default'].getPlugin('plugin'); // Default options for the plugin.

var defaults = {};
/**
 * An advanced Video.js plugin. For more information on the API
 *
 * See: https://blog.videojs.com/feature-spotlight-advanced-plugins/
 */

var Css = /*#__PURE__*/function (_Plugin) {
  _inheritsLoose__default['default'](Css, _Plugin);

  /**
   * Create a Css plugin instance.
   *
   * @param  {Player} player
   *         A Video.js Player instance.
   *
   * @param  {Object} [options]
   *         An optional options object.
   *
   *         While not a core part of the Video.js plugin architecture, a
   *         second argument of options is a convenient way to accept inputs
   *         from your plugin's caller.
   */
  function Css(player, options) {
    var _this;

    // the parent class will add player under this.player
    _this = _Plugin.call(this, player) || this;
    _this.options = videojs__default['default'].mergeOptions(defaults, options);

    if (_this.options.bigPlayButton) {
      var bigPlayButton = _this.player.bigPlayButton.el();

      for (var elem in _this.options.bigPlayButton) {
        bigPlayButton.style[elem] = _this.options.bigPlayButton[elem];
      }
    }

    if (_this.options.controlBar) {
      var controlBar = _this.player.controlBar.el();

      for (var _elem in _this.options.controlBar) {
        controlBar.style[_elem] = _this.options.controlBar[_elem];
      }
    }

    _this.player.ready(function () {
      _this.player.addClass('vjs-css');
    });

    return _this;
  }

  return Css;
}(Plugin); // Define default values for the plugin's `state` object here.


Css.defaultState = {}; // Include the version number.

Css.VERSION = version; // Register the plugin with video.js.

videojs__default['default'].registerPlugin('css', Css);

module.exports = Css;
